diff src/popupmnu.c @ 17817:e8a7029efa40 v8.1.1905

patch 8.1.1905: cannot set all properties of the info popup Commit: https://github.com/vim/vim/commit/c7c5f10a36fdeea353e026da28526ff9fb35e367 Author: Bram Moolenaar <Bram@vim.org> Date: Wed Aug 21 18:31:03 2019 +0200 patch 8.1.1905: cannot set all properties of the info popup Problem: Cannot set all properties of the info popup. Solution: Add popup_findinfo(). Rename popup_getpreview() to popup_findpreview().
author Bram Moolenaar <Bram@vim.org>
date Wed, 21 Aug 2019 18:45:04 +0200
parents 9ec2526c04c5
children 1f74a3c600a3
line wrap: on
line diff
--- a/src/popupmnu.c
+++ b/src/popupmnu.c
@@ -923,8 +923,8 @@ pum_set_selected(int n, int repeat UNUSE
     }
 #if defined(FEAT_TEXT_PROP) && defined(FEAT_QUICKFIX)
     if (!has_info)
-	// close any popup info window
-	popup_close_preview(TRUE);
+	// hide any popup info window
+	popup_hide_info();
 #endif
 
     if (!resized)
@@ -944,8 +944,8 @@ pum_undisplay(void)
     redraw_tabline = TRUE;
     status_redraw_all();
 #if defined(FEAT_TEXT_PROP) && defined(FEAT_QUICKFIX)
-    // close any popup info window
-    popup_close_preview(TRUE);
+    // hide any popup info window
+    popup_hide_info();
 #endif
 }